@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(COREBACKENDPARTITIONTABLE__H)
+#if !defined(KPMCORE_COREBACKENDPARTITIONTABLE_H)
 
-#define COREBACKENDPARTITIONTABLE__H
+#define KPMCORE_COREBACKENDPARTITIONTABLE_H
 
 #include "util/libpartitionmanagerexport.h"
 
