@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(COPYSOURCE__H)
+#if !defined(KPMCORE_COPYSOURCE_H)
 
-#define COPYSOURCE__H
+#define KPMCORE_COPYSOURCE_H
 
 #include <QtGlobal>
 
@@ -41,13 +41,12 @@ protected:
 
 public:
     virtual bool open() = 0;
-    virtual qint32 sectorSize() const = 0;
-    virtual bool readSectors(void* buffer, qint64 readOffset, qint64 numSectors) = 0;
+    virtual bool readData(QByteArray& buffer, qint64 readOffset, qint64 size) = 0;
     virtual qint64 length() const = 0;
     virtual bool overlaps(const CopyTarget& target) const = 0;
 
-    virtual qint64 firstSector() const = 0;
-    virtual qint64 lastSector() const = 0;
+    virtual qint64 firstByte() const = 0;
+    virtual qint64 lastByte() const = 0;
 
 private:
 };
