@@ -34,23 +34,20 @@ class CopyTarget;
 class CopySourceShred : public CopySource
 {
 public:
-    CopySourceShred(qint64 size, qint64 sectorsize, bool randomShred);
+    CopySourceShred(qint64 size, bool randomShred);
 
 public:
     bool open() override;
-    bool readSectors(void* buffer, qint64 readOffset, qint64 numSectors) override;
+    bool readData(QByteArray& buffer, qint64 readOffset, qint64 size) override;
     qint64 length() const override;
 
-    qint64 sectorSize() const override {
-        return m_SectorSize;    /**< @return the file's sector size */
-    }
     bool overlaps(const CopyTarget&) const override {
         return false;    /**< @return false for shred source */
     }
-    qint64 firstSector() const override {
+    qint64 firstByte() const override {
         return 0;    /**< @return 0 for shred source */
     }
-    qint64 lastSector() const override {
+    qint64 lastByte() const override {
         return length();    /**< @return equal to length for shred source. @see length() */
     }
 
@@ -67,7 +64,6 @@ protected:
 
 private:
     qint64 m_Size;
-    qint64 m_SectorSize;
     QFile m_SourceFile;
 };
 
