@@ -19,12 +19,10 @@
 
 /** Constructs a file to write to.
     @param filename name of the file to write to
-    @param sectorsize the "sector size" of the file to write to, usually the sector size of the CopySourceDevice
 */
-CopyTargetFile::CopyTargetFile(const QString& filename, qint64 sectorsize) :
+CopyTargetFile::CopyTargetFile(const QString& filename) :
     CopyTarget(),
-    m_File(filename),
-    m_SectorSize(sectorsize)
+    m_File(filename)
 {
 }
 
@@ -36,21 +34,20 @@ bool CopyTargetFile::open()
     return file().open(QIODevice::WriteOnly | QIODevice::Truncate);
 }
 
-/** Writes the given number of sectors from the given buffer to the file.
+/** Writes the given number of bytes from the given buffer to the file.
     @param buffer the data to write
     @param writeOffset where in the file to start writing
-    @param numSectors the number of sectors to write
     @return true on success
 */
-bool CopyTargetFile::writeSectors(void* buffer, qint64 writeOffset, qint64 numSectors)
+bool CopyTargetFile::writeData(QByteArray& buffer, qint64 writeOffset)
 {
-    if (!file().seek(writeOffset * sectorSize()))
+    if (!file().seek(writeOffset))
         return false;
 
-    bool rval = file().write(static_cast<char*>(buffer), numSectors * sectorSize()) == numSectors * sectorSize();
+    bool rval = file().write(buffer) == buffer.size();
 
     if (rval)
-        setSectorsWritten(sectorsWritten() + numSectors);
+        setBytesWritten(bytesWritten() + buffer.size());
 
     return rval;
 }
