@@ -23,7 +23,6 @@
 
 #include "core/operationstack.h"
 #include "core/device.h"
-#include "core/lvmdevice.h"
 #include "core/diskdevice.h"
 
 #include "fs/lvm2_pv.h"
@@ -65,23 +64,10 @@ void DeviceScanner::scan()
     clear();
 
     const QList<Device*> deviceList = CoreBackendManager::self()->backend()->scanDevices();
-    const QList<LvmDevice*> lvmList = LvmDevice::scanSystemLVM();
-    LVM::pvList = FS::lvm2_pv::getPVs(deviceList);
 
     for (const auto &d : deviceList)
         operationStack().addDevice(d);
 
     operationStack().sortDevices();
-
-    for (const auto &d : lvmList) {
-        operationStack().addDevice(d);
-        LVM::pvList.append(FS::lvm2_pv::getPVinNode(d->partitionTable()));
-    }
-
-    // Store list of physical volumes in LvmDevice
-    for (const auto &d : lvmList)
-        for (const auto &p : qAsConst(LVM::pvList))
-            if (p.vgName() == d->name())
-                d->physicalVolumes().append(p.partition());
 }
 
