@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(OPERATIONRUNNER__H)
+#if !defined(KPMCORE_OPERATIONRUNNER_H)
 
-#define OPERATIONRUNNER__H
+#define KPMCORE_OPERATIONRUNNER_H
 
 #include "util/libpartitionmanagerexport.h"
 
