@@ -63,7 +63,7 @@ class QTextStream;
 
 /** A partition or some unallocated space on a Device.
 
-    Repesent partitions in a PartitionTable on a Device. Partitions can be unallocated, thus not all
+    Represent partitions in a PartitionTable on a Device. Partitions can be unallocated, thus not all
     instances really are partitions in the way the user would see them.
 
     Extended partitions have child objects that represent the logicals inside them.
@@ -73,36 +73,6 @@ class QTextStream;
 */
 class LIBKPMCORE_EXPORT Partition : public PartitionNode
 {
-    friend class PartitionTable;
-    friend class OperationStack;
-    friend class Device;
-    friend class PartitionNode;
-    friend class CoreBackendPartitionTable;
-    friend class PartitionAlignment;
-
-    friend class PartResizerWidget;
-    friend class ResizeDialog;
-    friend class InsertDialog;
-    friend class NewDialog;
-    friend class EditMountPointDialog;
-    friend class PartPropsDialog;
-    friend class SizeDialogBase;
-
-    friend class CreateFileSystemOperation;
-    friend class RestoreOperation;
-    friend class SetPartFlagsOperation;
-    friend class CopyOperation;
-    friend class NewOperation;
-    friend class ResizeOperation;
-
-    friend class SetPartGeometryJob;
-    friend class CreatePartitionJob;
-    friend class SetPartFlagsJob;
-    friend class RestoreFileSystemJob;
-
-    friend class DeactivateVolumeGroupJob;
-
-    friend QTextStream& operator<<(QTextStream& stream, const Partition& p);
 
 public:
     /** A Partition state -- where did it come from? */
@@ -161,6 +131,12 @@ public:
     qint64 lastSector() const {
         return m_LastSector;    /**< @return the Partition's last sector on the Device */
     }
+    qint64 firstByte() const {
+        return firstSector() * sectorSize();    /**< @return the Partition's first byte on the Device */
+    }
+    qint64 lastByte() const {
+        return firstByte() + length() * sectorSize() - 1;    /**< @return the Partition's last byte on the Device */
+    }
     qint64 sectorsUsed() const;
     qint64 sectorSize() const {
         return m_SectorSize;    /**< @return the sector size on the Partition's Device */
@@ -235,7 +211,6 @@ public:
         m_UUID = s;    /**< @param s the new UUID */
     }
 
-protected:
     void append(Partition* p) override {
         m_Children.append(p);
     }
