@@ -119,10 +119,7 @@ bool PartitionNode::remove(Partition* p)
     if (p == nullptr)
         return false;
 
-    if (children().removeOne(p))
-        return true;
-
-    return false;
+    return children().removeOne(p);
 }
 
 /** Deletes all children */
@@ -139,11 +136,13 @@ void PartitionNode::clearChildren()
 */
 Partition* PartitionNode::findPartitionBySector(qint64 s, const PartitionRole& role)
 {
-    foreach(Partition * p, children()) {
+    const auto partitions = children();
+    for (auto &p : partitions) {
         // (women and) children first. ;-)
-        foreach(Partition * child, p->children())
-        if ((child->roles().roles() & role.roles()) && s >= child->firstSector() && s <= child->lastSector())
-            return child;
+        const auto pChildren = p->children();
+        for (auto &child : pChildren)
+            if ((child->roles().roles() & role.roles()) && s >= child->firstSector() && s <= child->lastSector())
+                return child;
 
         if ((p->roles().roles() & role.roles()) && s >= p->firstSector() && s <= p->lastSector())
             return p;
@@ -157,10 +156,10 @@ Partition* PartitionNode::findPartitionBySector(qint64 s, const PartitionRole& r
 */
 const Partition* PartitionNode::findPartitionBySector(qint64 s, const PartitionRole& role) const
 {
-    foreach(const Partition * p, children()) {
-        foreach(const Partition * child, p->children())
-        if ((child->roles().roles() & role.roles()) && s >= child->firstSector() && s <= child->lastSector())
-            return child;
+    for (const auto *p : children()) {
+        for (const auto &child : p->children())
+            if ((child->roles().roles() & role.roles()) && s >= child->firstSector() && s <= child->lastSector())
+                return child;
 
         if ((p->roles().roles() & role.roles()) && s >= p->firstSector() && s <= p->lastSector())
             return p;
@@ -190,9 +189,9 @@ qint32 PartitionNode::highestMountedChild() const
 {
     qint32 result = -1;
 
-    foreach(const Partition * p, children())
-    if (p->number() > result && p->isMounted())
-        result = p->number();
+    for (const auto * p : children())
+        if (p->number() > result && p->isMounted())
+            result = p->number();
 
     return result;
 }
@@ -200,9 +199,9 @@ qint32 PartitionNode::highestMountedChild() const
 /** @return true if any of the partition's children are mounted */
 bool PartitionNode::isChildMounted() const
 {
-    foreach(const Partition * child, children())
-    if (child->isMounted() || (child->hasChildren() && child->isChildMounted()))
-        return true;
+    for (const auto * child : children())
+        if (child->isMounted() || (child->hasChildren() && child->isChildMounted()))
+            return true;
 
     return false;
 }
