@@ -16,15 +16,14 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(PARTITIONROLE__H)
+#if !defined(KPMCORE_PARTITIONROLE_H)
 
-#define PARTITIONROLE__H
+#define KPMCORE_PARTITIONROLE_H
 
 #include "util/libpartitionmanagerexport.h"
 
 #include <QtGlobal>
-
-class QString;
+#include <QStringList>
 
 /** A Partition's role.
 
@@ -66,7 +65,7 @@ public:
         return !operator==(other);    /**< @param other object to compare with @return true if not the same */
     }
 
-    QString toString() const;
+    QString toString(const QStringList& languages = {}) const;
 
 private:
     Roles m_Roles;
