@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(SMARTATTRIBUTE__H)
+#if !defined(KPMCORE_SMARTATTRIBUTE_H)
 
-#define SMARTATTRIBUTE__H
+#define KPMCORE_SMARTATTRIBUTE_H
 
 #include "util/libpartitionmanagerexport.h"
 
