@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(EXTENDED__H)
+#if !defined(KPMCORE_EXTENDED_H)
 
-#define EXTENDED__H
+#define KPMCORE_EXTENDED_H
 
 #include "util/libpartitionmanagerexport.h"
 
