@@ -25,6 +25,7 @@
 #include <KLocalizedString>
 
 #include <QRegularExpression>
+#include <QRegularExpressionValidator>
 #include <QString>
 #include <QStringList>
 
@@ -96,11 +97,18 @@ qint64 fat16::maxCapacity() const
     return 4 * Capacity::unitFactor(Capacity::Byte, Capacity::GiB) - Capacity::unitFactor(Capacity::Byte, Capacity::MiB);
 }
 
-qint64 fat16::maxLabelLength() const
+int fat16::maxLabelLength() const
 {
     return 11;
 }
 
+QValidator* fat16::labelValidator(QObject *parent) const
+{
+    QRegularExpressionValidator *m_LabelValidator = new QRegularExpressionValidator(parent);
+    m_LabelValidator->setRegularExpression(QRegularExpression(QStringLiteral(R"(^[^\x{0000}-\x{001F}\x{007F}-\x{FFFF}*?.,;:\/\\|+=<>\[\]"]*$)")));
+    return m_LabelValidator;
+}
+
 qint64 fat16::readUsedCapacity(const QString& deviceNode) const
 {
     ExternalCommand cmd(QStringLiteral("fsck.fat"), { QStringLiteral("-n"), QStringLiteral("-v"), deviceNode });
@@ -131,9 +139,9 @@ qint64 fat16::readUsedCapacity(const QString& deviceNode) const
 
 bool fat16::writeLabel(Report& report, const QString& deviceNode, const QString& newLabel)
 {
-    report.line() << xi18nc("@info:progress", "Setting label for partition <filename>%1</filename> to %2", deviceNode, newLabel);
+    report.line() << xi18nc("@info:progress", "Setting label for partition <filename>%1</filename> to %2", deviceNode, newLabel.toUpper());
 
-    ExternalCommand cmd(report, QStringLiteral("fatlabel"), { deviceNode, newLabel });
+    ExternalCommand cmd(report, QStringLiteral("fatlabel"), { deviceNode, newLabel.toUpper() });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
@@ -151,11 +159,11 @@ bool fat16::create(Report& report, const QString& deviceNode)
 
 bool fat16::updateUUID(Report& report, const QString& deviceNode) const
 {
-    qint32 t = time(nullptr);
+    qint64 t = time(nullptr);
 
     char uuid[4];
     for (auto &u : uuid) {
-        u = t & 0xff;
+        u = static_cast<char>(t & 0xff);
         t >>= 8;
     }
 
