@@ -31,6 +31,7 @@
 #include "fs/hfs.h"
 #include "fs/hfsplus.h"
 #include "fs/hpfs.h"
+#include "fs/iso9660.h"
 #include "fs/jfs.h"
 #include "fs/linuxswap.h"
 #include "fs/luks.h"
@@ -40,6 +41,7 @@
 #include "fs/ocfs2.h"
 #include "fs/reiser4.h"
 #include "fs/reiserfs.h"
+#include "fs/udf.h"
 #include "fs/ufs.h"
 #include "fs/unformatted.h"
 #include "fs/unknown.h"
@@ -69,6 +71,7 @@ void FileSystemFactory::init()
     m_FileSystems.insert(FileSystem::Hfs, new FS::hfs(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::HfsPlus, new FS::hfsplus(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Hpfs, new FS::hpfs(-1, -1, -1, QString()));
+    m_FileSystems.insert(FileSystem::Iso9660, new FS::iso9660(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Jfs, new FS::jfs(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::LinuxSwap, new FS::linuxswap(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Luks, new FS::luks(-1, -1, -1, QString()));
@@ -78,6 +81,7 @@ void FileSystemFactory::init()
     m_FileSystems.insert(FileSystem::Ocfs2, new FS::ocfs2(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::ReiserFS, new FS::reiserfs(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Reiser4, new FS::reiser4(-1, -1, -1, QString()));
+    m_FileSystems.insert(FileSystem::Udf, new FS::udf(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Ufs, new FS::ufs(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Unformatted, new FS::unformatted(-1, -1, -1, QString()));
     m_FileSystems.insert(FileSystem::Unknown, new FS::unknown(-1, -1, -1, QString()));
@@ -98,7 +102,7 @@ void FileSystemFactory::init()
     @param label the FileSystem's label
     @return pointer to the newly created FileSystem object or nullptr if FileSystem could not be created
 */
-FileSystem* FileSystemFactory::create(FileSystem::Type t, qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label, const QString& uuid)
+FileSystem* FileSystemFactory::create(FileSystem::Type t, qint64 firstsector, qint64 lastsector, qint64 sectorSize, qint64 sectorsused, const QString& label, const QString& uuid)
 {
     FileSystem* fs = nullptr;
 
@@ -115,6 +119,7 @@ FileSystem* FileSystemFactory::create(FileSystem::Type t, qint64 firstsector, qi
     case FileSystem::Hfs:          fs = new FS::hfs(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::HfsPlus:      fs = new FS::hfsplus(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Hpfs:         fs = new FS::hpfs(firstsector, lastsector, sectorsused, label); break;
+    case FileSystem::Iso9660:      fs = new FS::iso9660(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Jfs:          fs = new FS::jfs(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::LinuxSwap:    fs = new FS::linuxswap(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Luks:         fs = new FS::luks(firstsector, lastsector, sectorsused, label); break;
@@ -124,6 +129,7 @@ FileSystem* FileSystemFactory::create(FileSystem::Type t, qint64 firstsector, qi
     case FileSystem::Ocfs2:        fs = new FS::ocfs2(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::ReiserFS:     fs = new FS::reiserfs(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Reiser4:      fs = new FS::reiser4(firstsector, lastsector, sectorsused, label); break;
+    case FileSystem::Udf:          fs = new FS::udf(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Ufs:          fs = new FS::ufs(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Unformatted:  fs = new FS::unformatted(firstsector, lastsector, sectorsused, label); break;
     case FileSystem::Unknown:      fs = new FS::unknown(firstsector, lastsector, sectorsused, label); break;
@@ -135,6 +141,7 @@ FileSystem* FileSystemFactory::create(FileSystem::Type t, qint64 firstsector, qi
     if (fs != nullptr)
         fs->setUUID(uuid);
 
+    fs->setSectorSize(sectorSize);
     return fs;
 }
 
@@ -143,7 +150,7 @@ FileSystem* FileSystemFactory::create(FileSystem::Type t, qint64 firstsector, qi
 */
 FileSystem* FileSystemFactory::create(const FileSystem& other)
 {
-    return create(other.type(), other.firstSector(), other.lastSector(), other.sectorsUsed(), other.label(), other.uuid());
+    return create(other.type(), other.firstSector(), other.lastSector(), other.sectorSize(), other.sectorsUsed(), other.label(), other.uuid());
 }
 
 /** @return the map of FileSystems */
@@ -159,5 +166,5 @@ const FileSystemFactory::FileSystems& FileSystemFactory::map()
 */
 FileSystem* FileSystemFactory::cloneWithNewType(FileSystem::Type newType, const FileSystem& other)
 {
-    return create(newType, other.firstSector(), other.lastSector(), other.sectorsUsed(), other.label());
+    return create(newType, other.firstSector(), other.lastSector(), other.sectorSize(), other.sectorsUsed(), other.label());
 }
