@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(HPFS__H)
+#if !defined(KPMCORE_HPFS_H)
 
-#define HPFS__H
+#define KPMCORE_HPFS_H
 
 #include "util/libpartitionmanagerexport.h"
 
