@@ -128,7 +128,7 @@ bool luks::create(Report& report, const QString& deviceNode)
                                 QStringLiteral("luksFormat"),
                                 deviceNode });
     if (!( createCmd.start(-1) &&
-                createCmd.write(m_passphrase.toUtf8() + '\n') == m_passphrase.toUtf8().length() + 1 &&
+                createCmd.write(m_passphrase.toLocal8Bit() + '\n') == m_passphrase.toLocal8Bit().length() + 1 &&
                 createCmd.waitFor() && createCmd.exitCode() == 0))
     {
         return false;
@@ -139,7 +139,7 @@ bool luks::create(Report& report, const QString& deviceNode)
                                 deviceNode,
                                 suggestedMapperName(deviceNode) });
 
-    if (!( openCmd.start(-1) &&  openCmd.write(m_passphrase.toUtf8() + '\n') == m_passphrase.toUtf8().length() + 1 && openCmd.waitFor()))
+    if (!( openCmd.start(-1) &&  openCmd.write(m_passphrase.toLocal8Bit() + '\n') == m_passphrase.toLocal8Bit().length() + 1 && openCmd.waitFor()))
         return false;
 
     scan(deviceNode);
@@ -262,7 +262,7 @@ bool luks::cryptOpen(QWidget* parent, const QString& deviceNode)
                                 suggestedMapperName(deviceNode) });
 
     if (!( openCmd.start(-1) &&
-                    openCmd.write(passphrase.toUtf8() + '\n') == passphrase.toUtf8().length() + 1 &&
+                    openCmd.write(passphrase.toLocal8Bit() + '\n') == passphrase.toLocal8Bit().length() + 1 &&
                     openCmd.waitFor() && openCmd.exitCode() == 0) )
         return false;
 
@@ -315,7 +315,7 @@ bool luks::cryptClose(const QString& deviceNode)
     m_innerFs = nullptr;
 
     m_passphrase.clear();
-    setLabel({});
+    setLabel(FileSystem::readLabel(deviceNode));
     setUUID(readUUID(deviceNode));
     setSectorsUsed(-1);
 
@@ -468,11 +468,12 @@ QString luks::suggestedMapperName(const QString& deviceNode) const
     return QStringLiteral("luks-") + readOuterUUID(deviceNode);
 }
 
-QString luks::readLabel(const QString&) const
+QString luks::readLabel(const QString& deviceNode) const
 {
     if (m_isCryptOpen && m_innerFs)
         return m_innerFs->readLabel(mapperName());
-    return QString();
+
+    return FileSystem::readLabel(deviceNode);
 }
 
 bool luks::writeLabel(Report& report, const QString&, const QString& newLabel)
@@ -572,7 +573,7 @@ void luks::getMapperName(const QString& deviceNode)
     m_MapperName = QString();
 
     if (cmd.run(-1) && cmd.exitCode() == 0) {
-        const QJsonDocument jsonDocument = QJsonDocument::fromJson(cmd.output().toUtf8());
+        const QJsonDocument jsonDocument = QJsonDocument::fromJson(cmd.output().toLocal8Bit());
         QJsonObject jsonObject = jsonDocument.object();
         const QJsonArray jsonArray = jsonObject[QLatin1String("blockdevices")].toArray();
         for (const auto &deviceLine : jsonArray) {
