@@ -17,9 +17,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(LUKS__H)
+#if !defined(KPMCORE_LUKS_H)
 
-#define LUKS__H
+#define KPMCORE_LUKS_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -41,7 +41,7 @@ class LIBKPMCORE_EXPORT luks : public FileSystem
 {
 public:
     luks(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
-    virtual ~luks();
+    ~luks() override;
 
 public:
     void init() override;
@@ -113,8 +113,6 @@ public:
         return m_Backup;
     }
     CommandSupportType supportSetLabel() const override {
-        if (!m_isCryptOpen)
-            return cmdSupportNone;
         if (m_Check && m_innerFs)
             return m_innerFs->supportSetLabel();
         return cmdSupportNone;
@@ -171,7 +169,7 @@ public:
     void getMapperName(const QString& deviceNode);
     void getLuksInfo(const QString& deviceNode);
 
-    FileSystem* innerFS() const { return m_innerFs; }; // avoid calling this unless necessary
+    FileSystem* innerFS() const { return m_innerFs; } // avoid calling this unless necessary
     QString outerUuid() const;
 
     QString mapperName() const { return m_MapperName; }
@@ -208,7 +206,6 @@ private:
     mutable bool m_cryptsetupFound;
     QString m_passphrase;
     bool m_isMounted;
-    constexpr static unsigned int m_logicalSectorSize = 512;
 
     QString m_MapperName;
     QString m_CipherName;
