@@ -104,7 +104,7 @@ qint64 nilfs2::maxCapacity() const
     return Capacity::unitFactor(Capacity::Byte, Capacity::EiB);
 }
 
-qint64 nilfs2::maxLabelLength() const
+int nilfs2::maxLabelLength() const
 {
     return 80;
 }
@@ -117,7 +117,7 @@ bool nilfs2::check(Report& report, const QString& deviceNode) const
 
 bool nilfs2::create(Report& report, const QString& deviceNode)
 {
-    ExternalCommand cmd(report, QStringLiteral("mkfs.nilfs2"), { deviceNode });
+    ExternalCommand cmd(report, QStringLiteral("mkfs.nilfs2"), { QStringLiteral("-f"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
