@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(CHECKFILESYSTEMJOB__H)
+#if !defined(KPMCORE_CHECKFILESYSTEMJOB_H)
 
-#define CHECKFILESYSTEMJOB__H
+#define KPMCORE_CHECKFILESYSTEMJOB_H
 
 #include "jobs/job.h"
 
