@@ -58,13 +58,16 @@ bool DeleteFileSystemJob::run(Report& parent)
     Report* report = jobStarted(parent);
 
     if (isMounted(partition().partitionPath())) {
-        report->line() << xi18nc("@info/plain", "Could not delete file system: file system on <filename>%1</filename> is mounted.", partition().deviceNode());
+        report->line() << xi18nc("@info:progress", "Could not delete file system: file system on <filename>%1</filename> is mounted.", partition().deviceNode());
         jobFinished(*report, rval);
         return false;
     }
 
-    if (partition().roles().has(PartitionRole::Extended))
+    if (partition().roles().has(PartitionRole::Extended)) {
         rval = true;
+    } else if (device().type() == Device::LVM_Device) {
+        rval = true;
+    }
     else {
         if (!partition().fileSystem().remove(*report, partition().deviceNode())) {
             jobFinished(*report, rval);
@@ -80,18 +83,18 @@ bool DeleteFileSystemJob::run(Report& parent)
                 rval = backendPartitionTable->clobberFileSystem(*report, partition());
 
                 if (!rval)
-                    report->line() << xi18nc("@info/plain", "Could not delete file system on <filename>%1</filename>.", partition().deviceNode());
+                    report->line() << xi18nc("@info:progress", "Could not delete file system on <filename>%1</filename>.", partition().deviceNode());
                 else
                     backendPartitionTable->commit();
 
                 delete backendPartitionTable;
 
             } else
-                report->line() << xi18nc("@info/plain", "Could not open partition table on device <filename>%1</filename> to delete file system on <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+                report->line() << xi18nc("@info:progress", "Could not open partition table on device <filename>%1</filename> to delete file system on <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
 
             delete backendDevice;
         } else
-            report->line() << xi18nc("@info/plain", "Could not delete file system signature for partition <filename>%1</filename>: Failed to open device <filename>%2</filename>.", partition().deviceNode(), device().deviceNode());
+            report->line() << xi18nc("@info:progress", "Could not delete file system signature for partition <filename>%1</filename>: Failed to open device <filename>%2</filename>.", partition().deviceNode(), device().deviceNode());
     }
 
     jobFinished(*report, rval);
@@ -101,5 +104,5 @@ bool DeleteFileSystemJob::run(Report& parent)
 
 QString DeleteFileSystemJob::description() const
 {
-    return xi18nc("@info/plain", "Delete file system on <filename>%1</filename>", partition().deviceNode());
+    return xi18nc("@info:progress", "Delete file system on <filename>%1</filename>", partition().deviceNode());
 }
