@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(DELETEFILESYSTEMJOB__H)
+#if !defined(KPMCORE_DELETEFILESYSTEMJOB_H)
 
-#define DELETEFILESYSTEMJOB__H
+#define KPMCORE_DELETEFILESYSTEMJOB_H
 
 #include "jobs/job.h"
 
