@@ -25,6 +25,7 @@
 
 #include "core/partition.h"
 #include "core/device.h"
+#include "core/lvmdevice.h"
 
 #include "util/report.h"
 
@@ -56,27 +57,32 @@ bool DeletePartitionJob::run(Report& parent)
 
     Report* report = jobStarted(parent);
 
-    CoreBackendDevice* backendDevice = CoreBackendManager::self()->backend()->openDevice(device().deviceNode());
+    if (device().type() == Device::Disk_Device) {
+        CoreBackendDevice* backendDevice = CoreBackendManager::self()->backend()->openDevice(device().deviceNode());
 
-    if (backendDevice) {
-        CoreBackendPartitionTable* backendPartitionTable = backendDevice->openPartitionTable();
+        if (backendDevice) {
+            CoreBackendPartitionTable* backendPartitionTable = backendDevice->openPartitionTable();
 
-        if (backendPartitionTable) {
-            rval = backendPartitionTable->deletePartition(*report, partition());
+            if (backendPartitionTable) {
+                rval = backendPartitionTable->deletePartition(*report, partition());
 
-            if (!rval)
-                report->line() << xi18nc("@info/plain", "Could not delete partition <filename>%1</filename>.", partition().deviceNode());
-            else
-                backendPartitionTable->commit();
+                if (!rval)
+                    report->line() << xi18nc("@info:progress", "Could not delete partition <filename>%1</filename>.", partition().deviceNode());
+                else
+                    backendPartitionTable->commit();
 
-            delete backendPartitionTable;
+                delete backendPartitionTable;
 
+            } else
+                report->line() << xi18nc("@info:progress", "Could not open partition table on device <filename>%1</filename> to delete partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+
+            delete backendDevice;
         } else
-            report->line() << xi18nc("@info/plain", "Could not open partition table on device <filename>%1</filename> to delete partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
-
-        delete backendDevice;
-    } else
-        report->line() << xi18nc("@info/plain", "Deleting partition failed: Could not open device <filename>%1</filename>.", device().deviceNode());
+            report->line() << xi18nc("@info:progress", "Deleting partition failed: Could not open device <filename>%1</filename>.", device().deviceNode());
+    } else if (device().type() == Device::LVM_Device) {
+        LvmDevice& dev = dynamic_cast<LvmDevice&>(device());
+        rval = LvmDevice::removeLV(*report, dev, partition());
+    }
 
     jobFinished(*report, rval);
 
@@ -85,5 +91,5 @@ bool DeletePartitionJob::run(Report& parent)
 
 QString DeletePartitionJob::description() const
 {
-    return xi18nc("@info/plain", "Delete the partition <filename>%1</filename>", partition().deviceNode());
+    return xi18nc("@info:progress", "Delete the partition <filename>%1</filename>", partition().deviceNode());
 }
