@@ -70,29 +70,32 @@ bool ResizeFileSystemJob::run(Report& parent)
     Report* report = jobStarted(parent);
 
     if (partition().fileSystem().length() == newLength()) {
-        report->line() << xi18ncp("@info/plain", "The file system on partition <filename>%2</filename> already has the requested length of 1 sector.", "The file system on partition <filename>%2</filename> already has the requested length of %1 sectors.", newLength(), partition().deviceNode());
+        report->line() << xi18ncp("@info:progress", "The file system on partition <filename>%2</filename> already has the requested length of 1 sector.", "The file system on partition <filename>%2</filename> already has the requested length of %1 sectors.", newLength(), partition().deviceNode());
         rval = true;
     } else {
-        report->line() << i18nc("@info/plain", "Resizing file system from %1 to %2 sectors.", partition().fileSystem().length(), newLength());
+        report->line() << i18nc("@info:progress", "Resizing file system from %1 to %2 sectors.", partition().fileSystem().length(), newLength());
 
         FileSystem::CommandSupportType support = (newLength() < partition().fileSystem().length()) ? partition().fileSystem().supportShrink() : partition().fileSystem().supportGrow();
 
         switch (support) {
         case FileSystem::cmdSupportBackend: {
             Report* childReport = report->newChild();
-            childReport->line() << i18nc("@info/plain", "Resizing a %1 file system using internal backend functions.", partition().fileSystem().name());
+            childReport->line() << xi18nc("@info:progress", "Resizing a %1 file system using internal backend functions.", partition().fileSystem().name());
             rval = resizeFileSystemBackend(*childReport);
             break;
         }
 
         case FileSystem::cmdSupportFileSystem: {
-            const qint64 newLengthInByte = Capacity(newLength() * device().logicalSectorSize()).toInt(Capacity::Byte);
-            rval = partition().fileSystem().resize(*report, partition().deviceNode(), newLengthInByte);
+            const qint64 newLengthInByte = Capacity(newLength() * device().logicalSize()).toInt(Capacity::Byte);
+            if (partition().isMounted())
+                rval = partition().fileSystem().resizeOnline(*report, partition().deviceNode(), partition().mountPoint(), newLengthInByte);
+            else
+                rval = partition().fileSystem().resize(*report, partition().deviceNode(), newLengthInByte);
             break;
         }
 
         default:
-            report->line() << xi18nc("@info/plain", "The file system on partition <filename>%1</filename> cannot be resized because there is no support for it.", partition().deviceNode());
+            report->line() << xi18nc("@info:progress", "The file system on partition <filename>%1</filename> cannot be resized because there is no support for it.", partition().deviceNode());
             break;
         }
 
@@ -120,17 +123,17 @@ bool ResizeFileSystemJob::resizeFileSystemBackend(Report& report)
             disconnect(CoreBackendManager::self()->backend(), &CoreBackend::progress, this, &ResizeFileSystemJob::progress);
 
             if (rval) {
-                report.line() << i18nc("@info/plain", "Successfully resized file system using internal backend functions.");
+                report.line() << xi18nc("@info:progress", "Successfully resized file system using internal backend functions.");
                 backendPartitionTable->commit();
             }
 
             delete backendPartitionTable;
         } else
-            report.line() << xi18nc("@info/plain", "Could not open partition <filename>%1</filename> while trying to resize the file system.", partition().deviceNode());
+            report.line() << xi18nc("@info:progress", "Could not open partition <filename>%1</filename> while trying to resize the file system.", partition().deviceNode());
 
         delete backendDevice;
     } else
-        report.line() << xi18nc("@info/plain", "Could not read geometry for partition <filename>%1</filename> while trying to resize the file system.", partition().deviceNode());
+        report.line() << xi18nc("@info:progress", "Could not read geometry for partition <filename>%1</filename> while trying to resize the file system.", partition().deviceNode());
 
     return rval;
 }
@@ -138,7 +141,7 @@ bool ResizeFileSystemJob::resizeFileSystemBackend(Report& report)
 QString ResizeFileSystemJob::description() const
 {
     if (isMaximizing())
-        return xi18nc("@info/plain", "Maximize file system on <filename>%1</filename> to fill the partition", partition().deviceNode());
+        return xi18nc("@info:progress", "Maximize file system on <filename>%1</filename> to fill the partition", partition().deviceNode());
 
-    return xi18ncp("@info/plain", "Resize file system on partition <filename>%2</filename> to 1 sector", "Resize file system on partition <filename>%2</filename> to %1 sectors", newLength(), partition().deviceNode());
+    return xi18ncp("@info:progress", "Resize file system on partition <filename>%2</filename> to 1 sector", "Resize file system on partition <filename>%2</filename> to %1 sectors", newLength(), partition().deviceNode());
 }
