@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(SETPARTGEOMETRYJOB__H)
+#if !defined(KPMCORE_SETPARTGEOMETRYJOB_H)
 
-#define SETPARTGEOMETRYJOB__H
+#define KPMCORE_SETPARTGEOMETRYJOB_H
 
 #include "jobs/job.h"
 
