@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(DELETEOPERATION__H)
+#if !defined(KPMCORE_DELETEOPERATION_H)
 
-#define DELETEOPERATION__H
+#define KPMCORE_DELETEOPERATION_H
 
 #include "util/libpartitionmanagerexport.h"
 
