@@ -20,6 +20,7 @@
 
 #include "util/report.h"
 
+#include <QtGlobal>
 #include <QString>
 #include <QStringList>
 
@@ -58,10 +59,10 @@ ExternalCommand::ExternalCommand(Report& report, const QString& cmd, const QStri
 
 void ExternalCommand::setup(const QProcess::ProcessChannelMode processChannelMode)
 {
-    setEnvironment(QStringList() << QStringLiteral("LC_ALL=C") << QStringLiteral("PATH=") + QString::fromUtf8(getenv("PATH")) << QStringLiteral("LVM_SUPPRESS_FD_WARNINGS=1"));
+    setEnvironment(QStringList() << QStringLiteral("LC_ALL=C") << QStringLiteral("PATH=") + QString::fromLocal8Bit(getenv("PATH")) << QStringLiteral("LVM_SUPPRESS_FD_WARNINGS=1"));
     setProcessChannelMode(processChannelMode);
 
-    connect(this, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &ExternalCommand::onFinished);
+    connect(this, qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this, &ExternalCommand::onFinished);
     connect(this, &ExternalCommand::readyReadStandardOutput, this, &ExternalCommand::onReadOutput);
 }
 
@@ -116,7 +117,7 @@ bool ExternalCommand::run(int timeout)
 
 void ExternalCommand::onReadOutput()
 {
-    const QString s = QString::fromUtf8(readAllStandardOutput());
+    const QByteArray s = readAllStandardOutput();
 
     if(m_Output.length() > 10*1024*1024) { // prevent memory overflow for badly corrupted file systems
         if (report())
@@ -127,7 +128,7 @@ void ExternalCommand::onReadOutput()
     m_Output += s;
 
     if (report())
-        *report() << s;
+        *report() << QString::fromLocal8Bit(s);
 }
 
 void ExternalCommand::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
