@@ -15,26 +15,39 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(HELPERS__H)
+#if !defined(KPMCORE_HELPERS_H)
 
-#define HELPERS__H
+#define KPMCORE_HELPERS_H
 
+#include "core/partition.h"
 #include "fs/filesystem.h"
+#include "fs/luks.h"
 
 #include "util/libpartitionmanagerexport.h"
 
+class KAboutData;
+
+class Partition;
 class QString;
-class QPoint;
-class QTreeWidget;
 
 LIBKPMCORE_EXPORT void registerMetaTypes();
-
 LIBKPMCORE_EXPORT bool caseInsensitiveLessThan(const QString& s1, const QString& s2);
-
-LIBKPMCORE_EXPORT void showColumnsContextMenu(const QPoint& p, QTreeWidget& tree);
-
 LIBKPMCORE_EXPORT bool checkAccessibleDevices();
-
 LIBKPMCORE_EXPORT bool isMounted(const QString& deviceNode);
+LIBKPMCORE_EXPORT KAboutData aboutKPMcore();
+
+/** Pointer to the file system (which might be inside LUKS container) contained in the partition
+ * @param p Partition where we look for file system
+ * @param fs inner FileSystem object
+*/
+template <typename T>
+inline LIBKPMCORE_EXPORT void innerFS (const Partition* p, T& fs)
+{
+    Partition* partition = const_cast<Partition*>(p);
+    if (p->roles().has(PartitionRole::Luks))
+        fs = dynamic_cast<const T>(dynamic_cast<const FS::luks* const>(&p->fileSystem())->innerFS());
+    else
+        fs = dynamic_cast<const T>(&partition->fileSystem());
+}
 
 #endif
